@@ -16,20 +16,6 @@ class Venue(models.Model):
             print 'venue does not exist at %s' % (venue_root)
             raise
 
-        self.VENUE_ROOT = os.path.abspath(venue_root)
-        self.VENUE_PATH, self.VENUE_DIRNAME = os.path.split(self.VENUE_ROOT)
-        self.VENUE_NAME = self.VENUE_DIRNAME
-
-        #ensure that the venue path is on sys.path
-        self.VENUE_PATH in sys.path or sys.path.insert(0,self.VENUE_PATH)
-        #load the django settings
-        self.get_settings()
-        #get this venue's acts
-        try:
-            self.get_acts()
-        except:
-            pass
-
     def get_settings(self):
         """ import the venue's settings.py"""
         try:
@@ -68,19 +54,6 @@ class Venue(models.Model):
         os.chdir(cwd)
         return
 
-    def get_acts(self):
-        """get this Venue's Acts and find out about them"""
-        from backstage.shortcuts import Act
-        self.acts = {}
-        acts_root = os.path.abspath(os.path.join(self.VENUE_ROOT, 'acts'))
-        acts_list = os.listdir(acts_root)
-        for a in acts_list:
-            try:
-                act = Act(self, a)
-                self.acts[a] = act
-            except:
-                pass
-
     def get_uwsgi_port(self):
         self.uwsgi_ip, self.uwsgi_port = uwsgi_portsniffer.get_uwsgi_port(self.UWSGI_INI)
         return
@@ -96,8 +69,6 @@ class Venue(models.Model):
         self.get_uwsgi_port()
         return
 
-
-
     def __unicode__(self):
         s = 'Backstage Venue instance %s at %s' % (self.VENUE_NAME, self.VENUE_ROOT)
         return s
@@ -105,6 +76,6 @@ class Venue(models.Model):
 
 
 
-class Act(models.model):
+class Act(models.Model):
     act_name = models.TextField(max_length=80)
     venue = models.ForeignKey(Venue)
\ No newline at end of file
